import { Checkbox, Divider, Radio, Space, Spin } from "antd";

import { TaxonomySlug, TermDto } from "@nice/common";

import { useEffect, useMemo, useState } from "react";
import { api } from "@nice/client";
import { useSearchParams } from "react-router-dom";
import TermSelect from "@web/src/components/models/term/term-select";
import { useMainContext } from "../../layout/MainProvider";

export default function FilterSection() {
	const { data: taxonomies } = api.taxonomy.getAll.useQuery({});
	const { setSelectedTerms } = useMainContext();
	const handleTermChange = (slug, selected) => {
		setSelectedTerms((prev) => ({
			...prev,
			[slug]: selected, // 更新对应 slug 的选择
		}));
	};
	return (
		<div className="bg-white p-6 rounded-lg shadow-sm space-y-6 h-full">
			{taxonomies?.map((tax, index) => {
				return (
					<div key={index}>
						<h3 className="text-lg font-medium mb-4">
							{tax?.name}
						</h3>
						<TermSelect
							className="w-72"
							multiple
							taxonomyId={tax?.id}
							onChange={(selected) =>
								handleTermChange(tax?.slug, selected)
							}></TermSelect>
						{index < taxonomies.length - 1 && (
							<Divider className="my-6" />
						)}
					</div>
				);
			})}
		</div>
	);
}
